use strict;
use warnings;
# VERSION  '0.01';

use parent qw( Alien::Base );

=head1 NAME

Alien::pipx - Find or install pipx

=head1 SYNOPSIS

Command line tool: pipx [options]

=head1 DESCRIPTION

This distribution provides the Python tool pipx so that it can be used by 
other Perl distributions that are on CPAN.  It does this by first trying to
detect an existing install of pipx on your system.  If found it
will use that.  If it cannot be found, it will download pipx for installation.
Note that the installation method varies by operating system. MacOS and Windows
users should have working installations of homebrew and scoop respectively.

=head1 METHODS

=head2 exe

 Alien::pipx->exe

Returns the command name for running the pipx utility.



=head1 SEE ALSO

=over 4

=item L<pipx|https://pipx.pypa.io/stable/>

pipx is a tool to help you install and run end-user applications written 
in Python. It's roughly similar to macOS's brew, JavaScript's npx, and
Linux's apt.

It's closely related to pip. In fact, it uses pip, but is focused on 
installing and managing Python packages that can be run from the command
line directly as applications. 

How is it Different from pip?

pip is a general-purpose package installer for both libraries and apps 
with no environment isolation. pipx is made specifically for application
installation, as it adds isolation yet still makes the apps available in
your shell: pipx creates an isolated environment for each application
and its associated packages.

pipx does not ship with pip, but installing it is often an important
part of bootstrapping your system.

=item L<Homebrew|https://brew.sh/>
Homebrew installs the stuff you need that Apple (or your Linux system) didn't.
*Eliminates permission popup windows
*Hides GUI wizard-style installers
*Prevents PATH pollution from installing lots of programs
*Avoids unexpected side-effects from installing and uninstalling programs
*Finds and installs dependencies automatically
*Performs all the extra setup steps itself to get a working program
=item L<Scoop|https://scoop.sh/>

Scoop is a command-line installer for Windows that:



=item L<Alien>

Documentation on the Alien concept itself.

=item L<Alien::Base>

The base class for this Alien.

=item L<Alien::Build::Manual::AlienUser>

Detailed manual for users of Alien classes.

=back

=head1 AUTHOR

Christos Argyropoulos <chrisarg@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2024 by Christos Argyropoulos.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

1;
